//$Id: num-entry.h,v 1.3 2001/08/31 16:11:38 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_WIDGETS_NUM_ENTRY_H
#define GUIKACHU_WIDGETS_NUM_ENTRY_H

#include <gtk--/spinbutton.h>
#include "property.h"

namespace Guikachu
{
    namespace GUI
    {
	class NumEntry: public Gtk::SpinButton
	{
	    Property<int> &property;
	public:
	    NumEntry (int min, int max,
		      Property<int> &property);
	    void set_min (int min);
	    void set_max (int max);
	    
	private:
	    bool update_block;
	    void update ();
	    
	    void changed_cb ();
	};
    }
}

#endif /* !GUIKACHU_WIDGETS_NUM_ENTRY_H */
